use crate::error::CustomError;

use super::registry::Registry;
use super::IObject;

#[derive(Debug)]
pub(crate) struct IHeading {
    pub(crate) level: organic::types::HeadlineLevel,
    pub(crate) title: Vec<IObject>,
}

impl IHeading {
    pub(crate) fn new<'parse>(
        registry: &mut Registry<'parse>,
        heading: &organic::types::Heading<'parse>,
    ) -> Result<IHeading, CustomError> {
        let title = heading
            .title
            .iter()
            .map(|obj| IObject::new(registry, obj))
            .collect::<Result<Vec<_>, _>>()?;
        Ok(IHeading {
            title,
            level: heading.level,
        })
    }
}
